;---------------------------------------------------------------------------------------
; This program was developed using NetLogo 3.1.4 (http://ccl.northwestern.edu/netlogo)
; by Roger Jovani and Volker Grimm in Leipzig (Germany) and Sevilla (Spain), 2007
; 
; It implements the model described in: 
;
;   Jovani, R. and Grimm, V. 2008. Breeding synchrony in colonial birds: from local stress 
;   to global harmony
; 
; This is the Basic Model including the Robustness Tests as discussed in that paper.
;
; The program is free of use for research and education. If you use this program or model
; for your own research, please refer to our paper as described above.
;
; Copyright: Roger Jovani and Volker Grimm, Leipzig and Sevilla, 2007
;-----------------------------------------------------------------------------------------


;---------------------------------------------------------------------------------------
; This program was modified using NetLogo 5.0 by James D.A. Millington ('JM' in comments below) in London (UK), 2012
;
; The modified model was used in:
;
;   Millington, J.D.A, O'Sullivan, D. and Perry, G.L.W. 2012. 
;   Model Histories: Narrative Explanation in Generative Simulation Modelling
;   Geoforum VOL & PAGES HERE
;   DOI: DOI HERE
;
; This modified version can be found at: URL HERE
;
; The original version of the model has been modified for three main reasons:
; i) to allow data output for analysis (e.g., output_data switch, create_movie switch, data_PrintToFile procedure)
; ii) to allow representation of variable numbers of influencing neighbouring birds (countN slider)
; iii) to allow full replicable model runs by allowing the user to specify the random number seed (seed slider)
;
; The modified program is free of use for research and education. If using this modified 
; version of the model, please cite both Jovani and Grimm 2008 and Millington et al. 2012 (as above)
;-----------------------------------------------------------------------------------------
 


globals
  [
  days                 ; One time step of the model corresponds to one day
  number_incubating    ; Number of incubating females
  maxpatch             ; Female with the highest initial OSL at the beginning of the simulation
  minpatch             ; Female with the lowest initial OSL at the beginning of the simulation
  available_habitat    ; Coordinates available for nesting
  unavailable_habitat  ; Coordinates unavailable for nesting
  firstLD      ; first laying day (added by JM 25/01/12)
  ] 

patches-own   
  [            
  STATE_old    ; "STATE" can be either 0 (pre-laying) or 1 (incubating)
  STATE_new    
  OSL_new      ; The bird's Own Stess Level 
  OSL_old
  OSL_list     ; History of bird's Stress Level (added by JM)
  NSL_list     ; History of bird's neighbours' Stress levels (added by JM)
  LD           ; Laying date: the day when the female lay its egg 
  AD           ; Arrival date: the day when the patch became occupied (added by JM)
  AOSL         ; Bird's stress level on arrival (added by JM)
  available    ; 0: the coordinates that will NOT be occupied by a female, 1: the coordinates will be occupied by a female
  ON           ; 0: the coordinates is still unoccupied, 1: the coordinates has been already occupied by a female
  N            ; neighbour agentset to calc meanNSL (added by JM)
  ]     
  
to setup
  
  clear-all                              ;added by JM for NetLogo version 5.0
  if(seed != 0) [ random-seed seed ]     ;added by JM (user sets seed = 0 to use CPU clock as seed)
  set number_incubating 0
  set days 0
  set firstLD 0 ;added by JM
  ask patches 
  [ 
    set available 1
    set STATE_old 0                ; All females start as pre-laying
    set ON 1                        
    set OSL_old 100 + random 201   ; Females start with a random Own Stress Level between 100 and 300
    set OSL_list [ 0 ]                                      ;added by JM
    set OSL_list lput OSL_old OSL_list                      ;added by JM
    set NSL_list [ 0 ]                                      ;added by JM
    set AOSL -1                                             ;added by JM
    set pcolor white 
    set LD 0                       ;added by JM for firstLD
    set N no-patches               ;patchset of neighbours (initially empty), added by JM
  ]   
  
  set unavailable_habitat n-of always_empty patches
  ask unavailable_habitat 
    [ 
      set available 0
      set pcolor black
      set ON 0 
      set OSL_old 0
    ]
  
  set available_habitat patches with [available = 1]  

  ask n-of initially_empty available_habitat
    [ 
      set ON 0
      set pcolor red
      set OSL_list remove-item 1 OSL_list ;added by JM
      set OSL_list lput 0 OSL_list        ;added by JM
    ]
  
  ;start addition by JM to output neighbours' OSL
  ask available_habitat [ update-neighbours ]
   
  ask available_habitat
  [
    ifelse (any? N)
    [ set NSL_list lput (precision (mean [OSL_old] of N) 1) NSL_list ]
    [ set NSL_list lput -1 NSL_list ] 
  ]
  ;end addition by JM
  
    
  set minpatch one-of available_habitat with [OSL_old = 100] 
  set maxpatch one-of available_habitat with [OSL_old = 300] 
  
  do-plots
  
  ;start addition by JM
  if(create_movie = true)
  [
    movie-start "BirdSynchrony.mov"
    movie-set-frame-rate 2
  ]
  ;end addition by JM
  
  reset-ticks              ;added by JM for NetLogo version 5.0
    
end
      
to go
  
  ;added by JM
  if(create_movie = true) [ movie-grab-interface ]
    
  step
  
  if(firstLD = 0 and any? patches with [LD != 0]) [ set firstLD days - 1 ]   ;added by JM
    
  ; Stop simulation after 200 days or if all females are breeding:
  if ((days = 200) or (number_incubating = ( world-width * world-height ) - always_empty )) 
  [
    if ( output_data = true ) [data_PrintToFile] ;added by JM
    print modes [LD] of patches ;added by JM
    
    ;added by JM
    if(create_movie = true) 
    [ 
      movie-grab-interface 
      movie-close
    ]
    ;end addition by JM
    
    stop
  ]
end
 
to step
  ; An arrival-rate fraction of those nests ready to be occupied are occupied by a female 
  ;ask available_habitat with [(ON = 0) and (any? neighbors with [ON = 1])]
  ask available_habitat with [ON = 0]
    [ 
      if random-float 1 < arrival-rate and count patches with [ON = 0] > always_empty  
      [ 
        set ON 1 
        set OSL_old 100 + random 101 ;added by JM 20/05/11 
        set AOSL OSL_old             ;added by JM 20/05/11 
        set AD days                  ;added by JM 18/05/11 
        set pcolor white             ;added by JM 18/05/11 
        
        set OSL_list reverse OSL_list        ;added by JM 18/05/11 
        set OSL_list remove-item 0 OSL_list  ;added by JM 18/05/11 
        set OSL_list fput OSL_old OSL_list   ;added by JM 18/05/11 
        set OSL_list reverse OSL_list        ;added by JM 18/05/11 
      ] 
    ]
    
   ask available_habitat with [ON = 1 and STATE_old = 0]
   [
     stress-level-dynamics
   ]
   
   ask patches [ set OSL_list lput (precision OSL_new 1) OSL_list ]   ;added by JM for output bird OSL history

   ;added by JM for output bird NSL history
   ask patches 
   [
     ifelse any? N
     [ set NSL_list lput (precision (mean [OSL_new] of N) 1) NSL_list ]  ;edited by JM 
     [ set NSL_list lput 0 NSL_list ]
   ]
   ;end addition by JM
   
   ask available_habitat with [ON = 1 and STATE_old = 0] 
   [
     ; Synchronous updating of states:
     set STATE_old STATE_new
     set OSL_old OSL_new
     
     ; for displaying laying dates (LD) in a green scale
     if STATE_old = 1    
     [ set pcolor scale-color green LD 0 50 ] 
   ]
         
   set days days + 1
   do-plots        
end

;function added by JM to control neighbours influencing stress level
to update-neighbours
  
  ;if the current number of neighbours influencing me is less than desired by user AND I have some neighbours present, add some neighbours
  if(count N < countN and count neighbors with [ON = 1] > 0)
  [
    ;if world-wrap is off and patch is at world edge, countN may be greater than the total number of neighbours a patch has
    ifelse(countN > count neighbors)
    
    ;if so, just add all neighbours
    [ set N neighbors with [ON = 1] ] ;set all possible neighbours with ON = 1
    
    ;otherwise, we only want to add up to countN neighbours, so we add neighbours not already in N until N = countN
    [ 
      let count_possN count neighbors with [ON = 1] ;first, check the number of neighbours with ON = 1
            
      ;if there are more neighbours than countN we need to be selective in which we add to N 
      ifelse(count_possN > countN) 
      [        
        let possN neighbors with [ON = 1] ;patchset of neighbours present
        
        let difference possN with [ not any? N with [ self = myself ] ] ;difference is the patchset of neighbours present that are not already in N
        
        let countNew countN - count N ;countNew is the number of new patches to add to N to bring the number of patches in N up to countN
        
        let N_to_add n-of countNew difference ;create a patchset of countNew patches not already in N (ready to add to N)
        
        set N (patch-set N N_to_add) ;add this new patchset to N
      ] 
      ;if there not more neighbours than countN, add them all
      [ set N neighbors with [ON = 1] ]
    ]  
  ]
  
end


   
to stress-level-dynamics
  ; "Noise" is an extra stress with values between SD and SD*2 experienced by a "stochasticity" random fraction of the colony each day
  let noise 0
  if random-float 1 < stochasticity
    [ set noise SD + random (SD + 1) ]   
  
  let meanNSL 0
  
  ;next four lines removed by JM from original code to allow variable number of neighbours to influence, replaced by subsequent code
  ; calculate the mean Stress Level of its 8 Neighbours (if there are)
  ; ifelse count neighbors with [ON = 1] > 0
  ;  [ set meanNSL mean [OSL_old] of neighbors with [ON = 1] ]
  ;  [ set meanNSL OSL_new ]
  
  ;next lines use number of neighbours specified by countN to calculate OSL; start addition by JM
  update-neighbours

  ifelse(any? N) ;if there are neighbours
  [ 
    ifelse(count N > 1) 
    [ set meanNSL mean [OSL_old] of N ] ;if there is more than one neighbour in OSL_old get the mean OSL of those neighbours
    [ set meanNSL sum [OSL_old] of N ] ;iof there is only one neighbour in OSL_old get the sum as NetLogo cannot calculate the mean of one value (sum of a single value is equal to its mean)
  ]
  [ set meanNSL OSL_new ] ;if there are no neighbours set meanNSL to my own OSL
  ;end addition by JM 
  
   
  ; [Eq A1] in Jovani & Grimm (2008)
  set OSL_new (1 - NR) * OSL_old + (NR * meanNSL) - SD + noise  

  ; if stress is below or equal to 10 the female lay its egg and this day becomes its laying date (LD)
  ifelse OSL_new <= 10             
      [ 
        set STATE_new  1 
        set OSL_new 0 
        set LD days 
        set number_incubating number_incubating + 1 
      ] 
      [ set STATE_new 0 ]           
end
    
to do-plots
  ; Plot stress dynamics for females with the highest and lowest initial OSL and 10 other females:
  set-current-plot "Stress examples"
  set-current-plot-pen "minOSL"
  plot [OSL_old] of minpatch
  set-current-plot-pen "patch1"
  plot [OSL_old] of patch 0 0
  set-current-plot-pen "patch2"
  plot [OSL_old] of patch 5 5
  set-current-plot-pen "patch3"
  plot [OSL_old] of patch 10 10
  set-current-plot-pen "patch4"
  plot [OSL_old] of patch 15 15
  set-current-plot-pen "patch5"
  plot [OSL_old] of patch 20 20
  set-current-plot-pen "patch6"
  plot [OSL_old] of patch 25 25
  set-current-plot-pen "patch7"
  plot [OSL_old] of patch 30 30 
  set-current-plot-pen "patch8"
  plot [OSL_old] of patch 35 35
  set-current-plot-pen "patch9"
  plot [OSL_old] of patch 40 40
  set-current-plot-pen "patch10"
  plot [OSL_old] of patch 45 45
  set-current-plot-pen "maxOSL"
  plot [OSL_old] of maxpatch
   
  ; Plot the histogram of laying dates:
  set-current-plot "Laying dates histogram" 
  set-current-plot-pen "LD"
  histogram [LD] of patches
  
end

;function added by JM to output patch OSL history to file
to data_PrintToFile
 
  file-close-all 
  let data_filename "AgentData_BirdSynchrony.txt"
  file-open data_filename
  
  ;write output file header
  file-type "[x y AD LD AOSL"
  
  let countN_list []
  let counter 1
  repeat countN 
  [ 
    set countN_list lput counter countN_list 
    set counter counter + 1
  ]
  
  foreach countN_list [ file-type word " Nx" ? ]
  foreach countN_list [ file-type word " Ny" ? ]
  foreach countN_list [ file-type word " NAD" ? ]
  foreach countN_list [ file-type word " NLD" ? ]
  
  let day 0
  repeat days + 1 
  [ 
    file-type" "
    file-type day
    set day day + 1
  ] 
  
  file-type "]"
  file-type "["
  
  set day 0
  repeat days + 1 
  [ 
    if(day != 0 ) [file-type" "]
    file-type day
    set day day + 1
  ] 
   
  file-print "]"
  
  ;ask patches to create final data list for output 
  ask available_habitat [set OSL_list remove-item 0 OSL_list]
  ask available_habitat [set NSL_list remove-item 0 NSL_list]

  ask available_habitat 
  [
    set N sort N
    while [length N < countN]
    [ set N fput -1 N ]
  ]

  ask available_habitat [foreach N [ ifelse(is-patch? ?) [ set OSL_list fput [LD] of ? OSL_list] [ set OSL_list fput ? OSL_list] ] ]
  ask available_habitat [foreach N [ ifelse(is-patch? ?) [ set OSL_list fput [AD] of ? OSL_list] [ set OSL_list fput ? OSL_list] ] ]
  ask available_habitat [foreach N [ ifelse(is-patch? ?) [ set OSL_list fput [pycor] of ? OSL_list] [ set OSL_list fput ? OSL_list] ] ]
  ask available_habitat [foreach N [ ifelse(is-patch? ?) [ set OSL_list fput [pxcor] of ? OSL_list] [ set OSL_list fput ? OSL_list] ] ]

  ask available_habitat [set OSL_list fput AOSL OSL_list]  
  ask available_habitat [set OSL_list fput LD OSL_list]
  ask available_habitat [set OSL_list fput AD OSL_list]
  ask available_habitat [set OSL_list fput pycor OSL_list]
  ask available_habitat [set OSL_list fput pxcor OSL_list]  

  ;ask patches to output data
  ask patches 
  [ 
    file-type OSL_list 
    file-print NSL_list
  ]
  
  file-close
  
  export-interface "AgentData_BirdSynchrony.png"
    
end    
@#$#@#$#@
GRAPHICS-WINDOW
601
40
1151
611
-1
-1
5.4
1
5
1
1
1
0
1
1
1
0
99
0
99
0
0
1
ticks
30.0

BUTTON
9
10
76
43
NIL
SETUP
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
81
10
144
43
NIL
GO
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
12
88
145
121
NR
NR
0
1
0.25
0.01
1
NIL
HORIZONTAL

BUTTON
150
10
213
43
STEP
step
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
12
328
206
373
incubating females (red patches)
count patches with [STATE_new = 1]\n
3
1
11

SLIDER
12
128
144
161
SD
SD
0
100
10
1
1
NIL
HORIZONTAL

TEXTBOX
161
137
445
165
Stress Decay each day owed to the enlargment of the day
11
0.0
0

SLIDER
12
167
143
200
STOCHASTICITY
STOCHASTICITY
0
1
0
0.01
1
NIL
HORIZONTAL

TEXTBOX
161
168
454
210
Proportion of randomly choosen females experiencing a stress between SD and SD*2 each day
11
0.0
0

PLOT
311
378
591
612
Laying dates histogram
laying date
# females
1.0
100.0
0.0
10.0
true
false
"" ""
PENS
"LD" 1.0 1 -16777216 true "" ""

PLOT
12
378
304
612
Stress examples
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"patch1" 1.0 0 -16777216 true "" ""
"patch2" 1.0 0 -16777216 true "" ""
"patch3" 1.0 0 -16777216 true "" ""
"patch4" 1.0 0 -16777216 true "" ""
"minOSL" 1.0 0 -2064490 true "" ""
"maxOSL" 1.0 0 -1184463 true "" ""
"patch5" 1.0 0 -16777216 true "" ""
"patch6" 1.0 0 -16777216 true "" ""
"patch7" 1.0 0 -16777216 true "" ""
"patch8" 1.0 0 -16777216 true "" ""
"patch9" 1.0 0 -16777216 true "" ""
"patch10" 1.0 0 -16777216 true "" ""

SLIDER
12
207
187
240
initially_empty
initially_empty
0
10000
2000
1
1
nests
HORIZONTAL

MONITOR
211
328
382
373
Available nest sites
count patches with [ON = 1]
3
1
11

SLIDER
12
284
142
317
arrival-rate
arrival-rate
0
1
0.15
0.05
1
NIL
HORIZONTAL

TEXTBOX
196
207
449
239
Number of initially empty nests that will be occupied during the simulation (displayed in red).
11
0.0
0

TEXTBOX
158
285
450
318
Proportion of initially_empty nests occupied each day from the number of remaining initially_empty nest sites.
11
0.0
0

SLIDER
11
246
188
279
always_empty
always_empty
0
10000
0
1
1
nests
HORIZONTAL

TEXTBOX
195
246
422
288
Number of locations unavailable for nesting (displayed in black).
11
0.0
1

TEXTBOX
160
101
396
129
Relevance given to the stress of neighbours
11
0.0
0

TEXTBOX
421
233
581
263
initially_empty + always_empty should be kept under 10000
11
105.0
0

TEXTBOX
623
14
1199
32
Map (aerial view) of the colony. Each small square is a female. Darker greens show earlier laying dates.
11
0.0
1

MONITOR
387
328
444
373
NIL
days
17
1
11

SWITCH
338
10
457
43
output_data
output_data
0
1
-1000

MONITOR
452
319
522
372
Mode LD
modes [LD] of patches
0
1
13

SWITCH
461
10
591
43
create_movie
create_movie
0
1
-1000

SLIDER
13
52
143
85
countN
countN
1
8
1
1
1
NIL
HORIZONTAL

MONITOR
526
319
589
372
First LD
firstLD
0
1
13

SLIDER
219
10
334
43
seed
seed
0
200
100
1
1
NIL
HORIZONTAL

TEXTBOX
159
63
433
91
Number of neighbours which influence stress of a bird
11
0.0
1

@#$#@#$#@
This program was developed using NetLogo 3.1.4 (http://ccl.northwestern.edu/netlogo)
by Roger Jovani and Volker Grimm in Leipzig (Germany) and Sevilla (Spain), 2007
 
It implements the model described in: 

Jovani, R. and Grimm, V. 2008. 
Breeding synchrony in colonial birds: from local stress to global harmony 
Proceedings of the Royal Society of London B 275, 1557–1563.
http://dx.doi.org/10.1098/rspb.2008.0125
 
This is the Basic Model including the Robustness Tests as discussed in that paper.

The program is free of use for research and education. If you use this program or model
for your own research, please refer to our paper as described above.

Copyright: Roger Jovani and Volker Grimm, Leipzig and Sevilla, 2007

----------------------------------------------------------------------------

The original program was modified using NetLogo 5.0 by James D.A. Millington ('JM' in code comments) in London (UK), 2012

The modified model is used in:

   Millington, J.D.A, O'Sullivan, D. and Perry, G.L.W. 2012. 
   Model Histories: Narrative Explanation in Generative Simulation Modelling
   Geoforum VOL & PAGES HERE
   DOI: DOI HERE

This modified version can be found on openabm.org at: URL HERE

The original version of the model has been modified for three main reasons:
i) to allow data output for analysis (e.g., output_data switch, create_movie switch, data_PrintToFile procedure)
ii) to allow representation of variable numbers of influencing neighbouring birds (countN slider)
iii) to allow full replicable model runs by allowing the user to specify the random number seed (seed slider)

The modified program is free of use for research and education. If using this modified 
version of the model, please cite both Jovani and Grimm, 2008 and Millington et al. 2012 (as above).
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

link
true
0
Line -7500403 true 150 0 150 300

link direction
true
0
Line -7500403 true 150 150 30 225
Line -7500403 true 150 150 270 225

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment1" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <exitCondition>count patches with [STATE_old = 1] = 1225</exitCondition>
    <metric>count patches with [STATE_old = 1]</metric>
    <metric>mean [LD] of patches</metric>
    <metric>max [LD] of patches</metric>
    <metric>min [LD] of patches</metric>
    <enumeratedValueSet variable="RNSL">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="OTSL">
      <value value="10"/>
    </enumeratedValueSet>
    <steppedValueSet variable="NR" first="0" step="0.1" last="1"/>
    <steppedValueSet variable="STOCHASTICITY" first="0" step="0.2" last="0.8"/>
    <enumeratedValueSet variable="SD">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment2" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="100"/>
    <exitCondition>count patches with [STATE_old = 1] = 1225</exitCondition>
    <metric>count patches with [STATE_old = 1]</metric>
    <metric>mean [LD] of patches</metric>
    <metric>max [LD] of patches</metric>
    <metric>min [LD] of patches</metric>
    <steppedValueSet variable="RNSL" first="50" step="1" last="55"/>
    <enumeratedValueSet variable="OTSL">
      <value value="10"/>
    </enumeratedValueSet>
    <steppedValueSet variable="NR" first="0" step="0.01" last="1"/>
    <enumeratedValueSet variable="SD">
      <value value="20"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="with MEANS" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="500"/>
    <exitCondition>count patches with [STATE_old = 1] = 100</exitCondition>
    <metric>count patches with [STATE_old = 1]</metric>
    <metric>mean [LD] of patches</metric>
    <metric>max [LD] of patches</metric>
    <metric>min [LD] of patches</metric>
    <metric>ask patches[</metric>
    <metric>print [pxcor]</metric>
    <metric>print [pycor]</metric>
    <metric>print [LD]</metric>
    <metric>]</metric>
    <enumeratedValueSet variable="NR">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SD">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="STOCHASTICITY">
      <value value="0.05"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="lineal decay" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <exitCondition>count patches with [STATE_old = 1] = 10000</exitCondition>
    <metric>count patches with [STATE_old = 1]</metric>
    <metric>median [LD] of patches</metric>
    <metric>max [LD] of patches</metric>
    <metric>min [LD] of patches</metric>
    <metric>standard-deviation [LD] of patches</metric>
    <steppedValueSet variable="NR" first="0.5" step="0.1" last="1.1"/>
    <enumeratedValueSet variable="SD">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="STOCHASTICITY">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="SD">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="STOCHASTICITY">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="NR">
      <value value="0.5"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="experiment" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <exitCondition>number_incubating = 10000</exitCondition>
    <enumeratedValueSet variable="arrival-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="STOCHASTICITY">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="NR" first="0" step="0.04" last="1.04"/>
    <enumeratedValueSet variable="always-empty">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SD">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="empty">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
